<?php
/**
 * @version	$Id
 * @package email2cloak
 * @author  Riccardo Zorn support@fasterjoomla.com
 * @copyright (C) 2014 - http://fasterjoomla.com
 * @license GNU/GPLv2 http://www.gnu.org/licenses/gpl-3.0.html
 */

defined('_JEXEC') or die;


class PlgContentEmail2Contact extends JPlugin
{

	public function onContentPrepare($context, &$row, &$params, $page = 0)
	{
		if (JPATH_BASE == JPATH_ADMINISTRATOR) {
		 	return false;
		}

		// Don't run this plugin when the content is being indexed

		if ($context == 'com_finder.indexer')
		{
			return true;
		}

		if (is_object($row))
		{
			return $this->_cloak($row->text, $params);
		}

		return $this->_cloak($row, $params);
	}


	
	/**
	 * Cloak all emails in text from spambots via Javascript.
	 *
	 * @param   string  &$text    The string to be cloaked.
	 * @param   mixed   &$params  Additional parameters. Parameter "mode" (integer, default 1)
	 *                             replaces addresses with "mailto:" links if nonzero.
	 *
	 * @return  boolean  True on success.
	 */
	protected function _cloak(&$text, &$params)
	{
		/*
		 * Check for presence of {emailcloak=off} which is explicits disables this
		 * bot for the item.
		 */
		
		if (JString::strpos($text, '{emailcloak=off}') !== false)
		{
			$text = JString::str_ireplace('{emailcloak=off}', '', $text);
			
			$mode = $this->params->def('mode','1');
			if ($mode == '1') {
				// we only want to exit if remove is true;
				return true;
			}
		}

		// Simple performance check to determine whether bot should process further.
		if (JString::strpos($text, '@') === false)
		{
			return true;
		}

		$replace = $this->params->def('replace', 0);
		
		if ($replace==0) {
			return true;
		} 
		
		// first, identify the email address, if any;
		// second, determine if it's in a url i.e. mailto:mail@example.com
		// third, replace it based on the options.
		$emailPattern =  '([\w\.\-]+\@[a-z0-9\.\-]+\.[a-zA-Z0-9\-]{2,10})';
		$patterns = array(
			'/'.'(mailto:)?'.$emailPattern.'/',
			'/'.'(mailto:)\s*'.$emailPattern.'([^>]*>[^<]*?)'.$emailPattern.'?/',
		);
		
		
		
		$text = preg_replace_callback($patterns[1], array(&$this,  'replaceEmails'), $text);
		$text = preg_replace_callback($patterns[0], array(&$this,  'replaceEmails'), $text);
		
		return true;
	}
	
	private function replaceEmails($matches) {
		$mailto = ($matches[1]);
		$email = ($matches[2]);
		$replace = $this->params->def('replace','1');
		$replacementText = JText::_($this->params->def('replacement_text','JGLOBAL_EMAIL'));
		
		$contactPage = $this->params->def('default_contact_page','');
		if ($replace=='1' && $contactPage) {
			// simply remove email addresses;
			$contactPage = '';
		}
		
		if (strlen($mailto)<3) {
			// this is a simple email in the text.
			if ($contactPage) {
				return "<a href='$contactPage'>$replacementText</a>";
			} else {
				return   $replacementText;
			}
		}
		
		// now we know it's a link.
		$closeTag = $secondMail = '';
		if (count($matches)>3) {
			$closeTag = ($matches[3]);
		}
		if (count($matches)>4) {
			$secondMail = ($matches[4]);
		}
		
		// moot now if (strlen($mailto>4)) 
		if (strlen($contactPage)<2) {
			$contactPage = '#';
		}
		
		if (strlen($secondMail)>3) {
			$secondMail = ' ' . $replacementText;
		} 
		
		return  $contactPage . $closeTag . ' ' . $secondMail ;
	}
}
